@@ -33,7 +33,7 @@ class EsHelper:
         :param pool: 连接池名称
         """
         if isinstance(pool, str):
-            self.pool, self.dialect = options.database[pool]
+            self.pool, self.conn_info = options.database[pool]
         else:
             self.pool = pool
 
