@@ -32,6 +32,7 @@ class RabbitMqHelper:
         else:
             raise Exception("missing queue")
         self.exchange = kwargs.pop("exchange", None)
+        exchange_kwargs = kwargs.pop("exchange_kwargs", {})
         credentials = pika.PlainCredentials(username, password)
         self.connection = pika.BlockingConnection(
             pika.ConnectionParameters(host=host, port=port, credentials=credentials, **kwargs))
@@ -39,7 +40,6 @@ class RabbitMqHelper:
         queue_kwargs = kwargs.get("queue_kwargs", {})
         self.channel.queue_declare(queue=self.queue, durable=True, **queue_kwargs)
         if self.exchange:
-            exchange_kwargs = kwargs.get("exchange_kwargs", {})
             self.channel.exchange_declare(exchange=self.exchange, **exchange_kwargs)
 
     def publish(self, message: str, exchange="", **kwargs):
