@@ -11,12 +11,12 @@ class MyThread(Thread):
             kwargs.pop("error_ignore")
         self.func = target
         self.args = args
-        self.kwargs = kwargs
+        self._kwargs = kwargs
         self.result = None
 
     def run(self):
         try:
-            self.result = self.func(*self.args, **self.kwargs)
+            self.result = self.func(*self.args, **self._kwargs)
         except Exception as e:
             if not self.error_ignore:
                 raise e
